@@ -1,5 +1,5 @@
 """" WorldStatus Definition """
-from rowantree.common.sdk import BaseModel
+from rowantree.contracts import BaseModel
 
 
 class WorldStatus(BaseModel):
